from typing import Any

class Downloader():
    """
    Should return a dict of downloaded JSON, json.loads()-ed
    """
    @staticmethod
    def download():
        raise NotImplementedError
